@@ -2,8 +2,9 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from ._inference import InferenceSessionClient
-from .client import Client, RawClient, Timeout
+from .client import Client, Timeout
 from .errors import HttpResponseError
+from .ops import Raw as RawClient
 
 __all__ = [
     "Client",
