@@ -37,6 +37,9 @@ from dyff.schema.platform import (
     Accelerator,
     Artifact,
     ArtifactURL,
+    Audit,
+    Challenge,
+    ChallengeTask,
     Concern,
     DataSchema,
     Dataset,
@@ -64,18 +67,28 @@ from dyff.schema.platform import (
     ModelSourceKinds,
     Module,
     OCIArtifact,
+    Pipeline,
+    PipelineRun,
+    PipelineRunStatus,
     Report,
     Resources,
     SafetyCase,
     Score,
     Status,
     StorageSignedURL,
+    Submission,
+    Team,
     UseCase,
     Volume,
 )
 from dyff.schema.requests import (
     AnalysisCreateRequest,
     ArtifactCreateRequest,
+    ChallengeContentEditRequest,
+    ChallengeCreateRequest,
+    ChallengeTaskCreateRequest,
+    ChallengeTaskRulesEditRequest,
+    ChallengeTeamCreateRequest,
     ConcernCreateRequest,
     DatasetCreateRequest,
     DocumentationEditRequest,
@@ -84,53 +97,35 @@ from dyff.schema.requests import (
     FamilyMembersEditRequest,
     InferenceServiceCreateRequest,
     InferenceSessionCreateRequest,
-    InferenceSessionTokenCreateRequest,
     LabelsEditRequest,
     MethodCreateRequest,
     ModelCreateRequest,
     ModuleCreateRequest,
+    PipelineCreateRequest,
+    PipelineRunRequest,
     ReportCreateRequest,
+    SubmissionCreateRequest,
+    TeamEditRequest,
 )
 from dyff.schema.responses import WorkflowLogEntry, WorkflowLogsResponse
 
-from ._generated.operations._operations import (
-    DatasetsOperations as DatasetsOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    EvaluationsOperations as EvaluationsOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    FamiliesOperations as FamiliesOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    InferenceservicesOperations as InferenceservicesOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    InferencesessionsOperations as InferencesessionsOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    MeasurementsOperations as MeasurementsOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    MethodsOperations as MethodsOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    ModelsOperations as ModelsOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    ModulesOperations as ModulesOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    ReportsOperations as ReportsOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    SafetycasesOperations as SafetycasesOperationsGenerated,
-)
-from ._generated.operations._operations import (
-    UsecasesOperations as UsecasesOperationsGenerated,
-)
 from ._inference import InferenceSessionClient
-from .errors import HttpResponseError
+from .errors import HTTPError, HttpResponseError
+from .ops import ChallengesOperations as ChallengesOperationsGenerated
+from .ops import DatasetsOperations as DatasetsOperationsGenerated
+from .ops import EvaluationsOperations as EvaluationsOperationsGenerated
+from .ops import FamiliesOperations as FamiliesOperationsGenerated
+from .ops import InferenceServicesOperations as InferenceServicesOperationsGenerated
+from .ops import InferenceSessionsOperations as InferenceSessionsOperationsGenerated
+from .ops import MeasurementsOperations as MeasurementsOperationsGenerated
+from .ops import MethodsOperations as MethodsOperationsGenerated
+from .ops import ModelsOperations as ModelsOperationsGenerated
+from .ops import ModulesOperations as ModulesOperationsGenerated
+from .ops import PipelinesOperations as PipelinesOperationsGenerated
+from .ops import ReportsOperations as ReportsOperationsGenerated
+from .ops import SafetyCasesOperations as SafetyCasesOperationsGenerated
+from .ops import TeamsOperations as TeamsOperationsGenerated
+from .ops import UseCasesOperations as UseCasesOperationsGenerated
 
 if typing.TYPE_CHECKING:
     from .client import Client
@@ -139,16 +134,7 @@ if typing.TYPE_CHECKING:
 QueryT = Union[str, dict[str, Any], list[dict[str, Any]]]
 
 
-class _OpsProtocol(Protocol):
-    @property
-    def _insecure(self) -> bool: ...
-
-    @property
-    def _timeout(self) -> Timeout: ...
-
-    @property
-    def _raw_ops(self) -> Any: ...
-
+class _LabeledProtocol(Protocol):
     def label(self, resource_id: str, labels: dict[str, Optional[str]]) -> None:
         """Label the specified resource with key-value pairs (stored in the ``.labels``
         field of the resource).
@@ -164,6 +150,17 @@ class _OpsProtocol(Protocol):
         ...
 
 
+class _OpsProtocol(_LabeledProtocol, Protocol):
+    @property
+    def _insecure(self) -> bool: ...
+
+    @property
+    def _timeout(self) -> Timeout: ...
+
+    @property
+    def _raw_ops(self) -> Any: ...
+
+
 class _ArtifactsProtocol(_OpsProtocol, Protocol):
     def downlinks(self, id: str) -> list[ArtifactURL]: ...
 
@@ -209,7 +206,7 @@ def _retry_not_found(fn):
         while True:
             try:
                 return fn(*args, **kwargs)
-            except HttpResponseError as ex:
+            except (HTTPError, HttpResponseError) as ex:
                 if ex.status_code == 404 and retries < len(delays):
                     time.sleep(delays[retries])
                     retries += 1
@@ -296,6 +293,7 @@ def _parse_schema_object(
 
 _EntityT = TypeVar(
     "_EntityT",
+    Challenge,
     Dataset,
     Evaluation,
     Family,
@@ -306,14 +304,17 @@ _EntityT = TypeVar(
     Model,
     Module,
     OCIArtifact,
+    Pipeline,
     Report,
     SafetyCase,
+    Team,
     UseCase,
 )
 _CreateRequestT = TypeVar(
     "_CreateRequestT",
     AnalysisCreateRequest,
     ArtifactCreateRequest,
+    ChallengeCreateRequest,
     ConcernCreateRequest,
     DatasetCreateRequest,
     EvaluationCreateRequest,
@@ -323,10 +324,12 @@ _CreateRequestT = TypeVar(
     MethodCreateRequest,
     ModelCreateRequest,
     ModuleCreateRequest,
+    PipelineCreateRequest,
     ReportCreateRequest,
 )
 _CreateResponseT = TypeVar(
     "_CreateResponseT",
+    Challenge,
     Dataset,
     Evaluation,
     Family,
@@ -337,24 +340,29 @@ _CreateResponseT = TypeVar(
     Model,
     Module,
     OCIArtifact,
+    Pipeline,
     Report,
     SafetyCase,
+    Team,
     UseCase,
 )
 _RawOpsT = TypeVar(
     "_RawOpsT",
+    ChallengesOperationsGenerated,
     DatasetsOperationsGenerated,
     EvaluationsOperationsGenerated,
     FamiliesOperationsGenerated,
-    InferenceservicesOperationsGenerated,
-    InferencesessionsOperationsGenerated,
+    InferenceServicesOperationsGenerated,
+    InferenceSessionsOperationsGenerated,
     MeasurementsOperationsGenerated,
     MethodsOperationsGenerated,
     ModelsOperationsGenerated,
     ModulesOperationsGenerated,
+    PipelinesOperationsGenerated,
     ReportsOperationsGenerated,
-    SafetycasesOperationsGenerated,
-    UsecasesOperationsGenerated,
+    SafetyCasesOperationsGenerated,
+    TeamsOperationsGenerated,
+    UseCasesOperationsGenerated,
 )
 
 
@@ -386,6 +394,20 @@ class _OpsBase(Generic[_EntityT, _CreateRequestT, _CreateResponseT, _RawOpsT]):
     def _raw_ops(self) -> _RawOpsT:
         return self.__raw_ops
 
+    def create(self, request: SchemaObject[_CreateRequestT]) -> _CreateResponseT:
+        """Create a new entity.
+
+        .. note::
+            This operation may incur compute costs.
+
+        :param request: The entity create request specification.
+        :return: A full entity spec with its .id and other system properties set
+        """
+        request = _parse_schema_object(self._request_type, request)
+        payload = request.model_dump(mode="json")
+        entity = _retry_not_found(self._raw_ops.create)(payload)
+        return self._response_type.model_validate(entity)
+
     def get(self, id: str) -> _EntityT:
         """Get an entity by its .id.
 
@@ -417,22 +439,9 @@ class _OpsBase(Generic[_EntityT, _CreateRequestT, _CreateResponseT, _RawOpsT]):
         """
         if not labels:
             return
-        labels = LabelsEditRequest(labels=labels).dict()  # type: ignore
+        labels = LabelsEditRequest(labels=labels).model_dump(by_alias=True)
         self._raw_ops.label(id, labels)
 
-    def create(self, request: SchemaObject[_CreateRequestT]) -> _CreateResponseT:
-        """Create a new entity.
-
-        .. note::
-            This operation may incur compute costs.
-
-        :param request: The entity create request specification.
-        :return: A full entity spec with its .id and other system properties set
-        """
-        request = _parse_schema_object(self._request_type, request)
-        entity = _retry_not_found(self._raw_ops.create)(request.model_dump(mode="json"))
-        return self._response_type.model_validate(entity)
-
     def _request(self, method: str, route: str, **kwargs) -> httpx.Response:
         if kwargs.pop("verify", None) is not None:
             raise ValueError(
@@ -572,7 +581,7 @@ class _NewOpsBase(Generic[_EntityT, _CreateRequestT, _CreateResponseT]):
         return response
 
 
-class _PublishMixin(_OpsProtocol):
+class _PublishMixin(_LabeledProtocol):
     def publish(
         self,
         id: str,
@@ -599,7 +608,7 @@ class _PublishMixin(_OpsProtocol):
         return self.label(id, _access_label(access))
 
 
-class _ConcernsMixin(_OpsProtocol):
+class _ConcernsMixin(_LabeledProtocol):
     def add_concern(self, id: str, concern: Concern) -> None:
         """Label the entity with a link to a relevant Concern."""
         return self.label(id, {concern.label_key(): concern.label_value()})
@@ -690,7 +699,7 @@ class _DocumentationMixin(_OpsProtocol):
         :raises HttpResponseError:
         """
         return Documentation.model_validate(
-            self._raw_ops.edit_documentation(id, edit_request.dict())
+            self._raw_ops.edit_documentation(id, edit_request.model_dump(by_alias=True))
         )
 
 
@@ -747,7 +756,6 @@ class _LogsMixin(_OpsProtocol):
 
 class _Artifacts(
     _NewOpsBase[OCIArtifact, ArtifactCreateRequest, OCIArtifact],
-    _DocumentationMixin,
     _PublishMixin,
 ):
     """Operations on :class:`~dyff.schema.platform.OCIArtifact` entities.
@@ -865,6 +873,65 @@ class _Artifacts(
         return Status.model_validate(response.json())
 
 
+class _Challenges(
+    _OpsBase[
+        Challenge, ChallengeCreateRequest, Challenge, ChallengesOperationsGenerated
+    ],
+    _PublishMixin,
+):
+    """Operations on :class:`~dyff.schema.platform.Challenge` entities.
+
+    .. note::
+
+        Do not instantiate this class. Access it through the
+        ``.challenges`` attribute of :class:`~dyff.client.Client`.
+    """
+
+    def __init__(
+        self,
+        _client: Client,
+    ):
+        super().__init__(
+            _client=_client,
+            _entity_type=Challenge,
+            _request_type=ChallengeCreateRequest,
+            _response_type=Challenge,
+            _raw_ops=_client.raw.challenges,
+        )
+
+    def create_task(
+        self, id: str, request: ChallengeTaskCreateRequest
+    ) -> ChallengeTask:
+        result = self._raw_ops.create_task(id, request.model_dump(mode="json"))
+        return ChallengeTask.model_validate(result)
+
+    def create_team(self, id: str, request: ChallengeTeamCreateRequest) -> Team:
+        result = self._raw_ops.create_team(id, request.model_dump(mode="json"))
+        return Team.model_validate(result)
+
+    def edit_content(self, id: str, edit: ChallengeContentEditRequest) -> None:
+        self._raw_ops.edit_content(id, edit.model_dump(mode="json"))
+
+    def edit_task_content(
+        self, id: str, task_id: str, edit: ChallengeContentEditRequest
+    ) -> None:
+        self._raw_ops.edit_task_content(id, task_id, edit.model_dump(mode="json"))
+
+    def edit_task_rules(
+        self, id: str, task_id: str, edit: ChallengeTaskRulesEditRequest
+    ) -> None:
+        return self._raw_ops.edit_task_rules(id, task_id, edit.model_dump(mode="json"))
+
+    def submit(
+        self, id: str, task_id: str, request: SubmissionCreateRequest
+    ) -> Submission:
+        submission = self._raw_ops.submit(id, task_id, request.model_dump(mode="json"))
+        return Submission.model_validate(submission)
+
+    def teams(self, id: str) -> list[Team]:
+        return [Team.model_validate(team) for team in self._raw_ops.teams(id)]
+
+
 class _Datasets(
     _OpsBase[Dataset, DatasetCreateRequest, Dataset, DatasetsOperationsGenerated],
     _ArtifactsMixin,
@@ -1182,7 +1249,7 @@ class _Families(
         """
         if not members:
             return
-        edit = FamilyMembersEditRequest(members=members).dict()  # type: ignore
+        edit = FamilyMembersEditRequest(members=members).model_dump(by_alias=True)
         self._raw_ops.edit_members(id, edit)
 
     # FIXME: This method should be provided by _DocumentationMixin, but first
@@ -1197,7 +1264,7 @@ class _Families(
         :param id: The ID of the entity.
         :param edit_request: Object containing the edits to make.
         """
-        self._raw_ops.edit_documentation(id, edit_request.dict())
+        self._raw_ops.edit_documentation(id, edit_request.model_dump(by_alias=True))
 
 
 class _InferenceServices(
@@ -1205,7 +1272,7 @@ class _InferenceServices(
         InferenceService,
         InferenceServiceCreateRequest,
         InferenceService,
-        InferenceservicesOperationsGenerated,
+        InferenceServicesOperationsGenerated,
     ],
     _DocumentationMixin,
     _PublishMixin,
@@ -1277,7 +1344,7 @@ class _InferenceSessions(
         InferenceSession,
         InferenceSessionCreateRequest,
         InferenceSessionAndToken,
-        InferencesessionsOperationsGenerated,
+        InferenceSessionsOperationsGenerated,
     ]
 ):
     """Operations on :class:`~dyff.schema.platform.Inferencesession` entities.
@@ -1402,7 +1469,7 @@ class _InferenceSessions(
         return InferenceSessionClient(
             session_id=session_id,
             token=token,
-            dyff_api_endpoint=self._raw_ops._client._base_url,
+            dyff_api_endpoint=self._client._endpoint,
             inference_endpoint=endpoint,
             input_adapter=input_adapter,
             output_adapter=output_adapter,
@@ -1410,24 +1477,43 @@ class _InferenceSessions(
         )
 
     def ready(self, session_id: str) -> bool:
-        """Return True if the session is ready to receive inference input.
-
-        The readiness probe is expected to fail with status codes 404 or 503,
-        as these will occur at times during normal session start-up. The
-        ``ready()`` method returns False in these cases. Any other status
-        codes will raise an ``HttpResponseError``.
-
-        :param str session_id: The ID of the session.
-        :raises HttpResponseError:
-        """
+        """Return True if the session is ready; tolerate 202/JSON bodies; GET→POST
+        fallback."""
+        # Try GET first
         try:
-            self._raw_ops.ready(session_id)
-        except HttpResponseError as ex:
-            if ex.status_code in [404, 503]:
+            resp = self._request("GET", f"/inferencesessions/{session_id}/ready")
+            sc = resp.status_code
+            if sc == 202:
                 return False
-            else:
+            if sc == 204:
+                return True
+            if sc == 200:
+                try:
+                    data = resp.json()
+                    if isinstance(data, dict) and "ready" in data:
+                        return bool(data["ready"])
+                except Exception:
+                    pass
+                return True
+            # Any other 2xx: assume ready
+            return True
+        except httpx.HTTPStatusError as ex:
+            sc = ex.response.status_code
+            if sc in (404, 503):
+                return False
+            if sc != 405:
                 raise
-        return True
+        # Fallback to POST (older API)
+        try:
+            resp = self._request("POST", f"/inferencesessions/{session_id}/ready")
+            sc = resp.status_code
+            if sc == 202:
+                return False
+            return sc in (200, 204)
+        except httpx.HTTPStatusError as ex:
+            if ex.response.status_code in (404, 503, 405):
+                return False
+            raise
 
     def terminate(self, session_id: str) -> Status:
         """Terminate a session.
@@ -1439,20 +1525,34 @@ class _InferenceSessions(
         return Status.model_validate(self._raw_ops.terminate(session_id))
 
     def token(self, session_id: str, *, expires: Optional[datetime] = None) -> str:
-        """Create a session token.
-
-        The session token is a short-lived token that allows the bearer to
-        make inferences with the session (via an ``InferenceSessionClient``)
-        and to call ``ready()``, ``get()``, and ``terminate()`` on the session.
-
-        :param str session_id: The ID of the session.
-        :keyword Optional[datetime] expires: The expiration time of the token.
-            Must be < the expiration time of the session. Default: expiration
-            time of the session.
-        :raises HttpResponseError:
-        """
-        request = InferenceSessionTokenCreateRequest(expires=expires)
-        return str(self._raw_ops.token(session_id, request.dict()))
+        """Create a short-lived session token (POST for new servers; GET fallback)."""
+        body = {"expires": expires.isoformat()} if expires is not None else None
+        # Prefer POST (newer API)
+        try:
+            resp = self._request(
+                "POST",
+                f"/inferencesessions/{session_id}/token",
+                json=body,
+            )
+            ct = resp.headers.get("content-type", "").lower()
+            if "application/json" in ct:
+                payload = resp.json()
+                if isinstance(payload, dict) and "token" in payload:
+                    return str(payload["token"])
+                if isinstance(payload, str):
+                    return payload
+            return resp.text
+        except httpx.HTTPStatusError as ex:
+            # Older servers may only support GET
+            if ex.response.status_code != 405:
+                raise
+        # Fallback to GET (legacy)
+        raw = self._raw_ops.token(session_id)
+        if isinstance(raw, (bytes, bytearray)):
+            return raw.decode()
+        if isinstance(raw, dict) and "token" in raw:
+            return str(raw["token"])
+        return str(raw)
 
 
 class _Measurements(
@@ -1580,11 +1680,10 @@ class _Measurements(
         :yield: Individual log entries as they arrive.
         :raises HttpResponseError:
         """
-        # Build WebSocket URL
-        base_url = self._client._raw._client._base_url.replace("https://", "").replace(
-            "http://", ""
+        ws_endpoint = self._client._endpoint.replace("https://", "wss://").replace(
+            "http://", "ws://"
         )
-        ws_url = f"wss://{base_url}/v0/measurements/{id}/logs/workflow/stream"
+        ws_url = f"{ws_endpoint}/measurements/{id}/logs/workflow/stream"
 
         # Connect to WebSocket with authentication
         headers = {"Authorization": f"Bearer {self._client._api_token}"}
@@ -1700,7 +1799,7 @@ class _Methods(
 
         # Make HTTP request to the methods workflow logs endpoint
         response = httpx.get(
-            f"{self._client._raw._client._base_url}/methods/{id}/logs/workflow",
+            f"{self._client._endpoint}/methods/{id}/logs/workflow",
             headers={"Authorization": f"Bearer {self._client._api_token}"},
             params=params,
             verify=not self._insecure,
@@ -1716,11 +1815,10 @@ class _Methods(
         :yield: Individual log entries as they arrive.
         :raises HttpResponseError:
         """
-        # Build WebSocket URL
-        base_url = self._client._raw._client._base_url.replace("https://", "").replace(
-            "http://", ""
+        ws_endpoint = self._client._endpoint.replace("https://", "wss://").replace(
+            "http://", "ws://"
         )
-        ws_url = f"wss://{base_url}/methods/{id}/logs/workflow/stream"
+        ws_url = f"{ws_endpoint}/methods/{id}/logs/workflow/stream"
 
         # Connect to WebSocket with authentication
         api_token = self._client._api_token
@@ -1838,7 +1936,6 @@ class _Models(
             have a concept of symlinks.
         :returns: The complete Model resource.
         """
-        print(list(root_directory.rglob("*")))
         root_directory = Path(root_directory)
         file_paths = [
             file_path
@@ -1947,7 +2044,7 @@ class _Models(
 
         # Make HTTP request to the models workflow logs endpoint
         response = httpx.get(
-            f"{self._client._raw._client._base_url}/models/{id}/logs/workflow",
+            f"{self._client._endpoint}/models/{id}/logs/workflow",
             headers={"Authorization": f"Bearer {self._client._api_token}"},
             params=params,
             verify=not self._insecure,
@@ -1963,11 +2060,10 @@ class _Models(
         :yield: Individual log entries as they arrive.
         :raises HttpResponseError:
         """
-        # Build WebSocket URL
-        base_url = self._client._raw._client._base_url.replace("https://", "").replace(
-            "http://", ""
+        ws_endpoint = self._client._endpoint.replace("https://", "wss://").replace(
+            "http://", "ws://"
         )
-        ws_url = f"wss://{base_url}/models/{id}/logs/workflow/stream"
+        ws_url = f"{ws_endpoint}/models/{id}/logs/workflow/stream"
 
         # Connect to WebSocket with authentication
         api_token = self._client._api_token
@@ -2135,6 +2231,42 @@ class _Modules(
         _retry_not_found(self._raw_ops.finalize)(module.id)
 
 
+class _Pipelines(
+    _OpsBase[
+        Pipeline,
+        PipelineCreateRequest,
+        Pipeline,
+        PipelinesOperationsGenerated,
+    ],
+    _DocumentationMixin,
+    _PublishMixin,
+):
+    def __init__(self, _client: Client):
+        super().__init__(
+            _client=_client,
+            _entity_type=Pipeline,
+            _request_type=PipelineCreateRequest,
+            _response_type=Pipeline,
+            _raw_ops=_client.raw.pipelines,
+        )
+
+    def run(self, id: str, request: PipelineRunRequest) -> PipelineRun:
+        if isinstance(request, dict):
+            request = PipelineRunRequest.model_validate(request)
+        entity = self._raw_ops.run(id, request.model_dump())
+        return PipelineRun.model_validate(entity)
+
+    def get_run_status(self, id: str) -> PipelineRunStatus:
+        entity = self._raw_ops.get_run_status(id)
+        return PipelineRunStatus.model_validate(entity)
+
+    # def query(self, query: QueryT | None = None) -> list[Pipeline]:
+    #     response = self._request(
+    #         "GET", "/pipelines", params={"query": _encode_query(query)}
+    #     )
+    #     return [Pipeline.model_validate(d) for d in response.json()]
+
+
 class _Reports(
     _OpsBase[
         Report,
@@ -2219,7 +2351,7 @@ class _SafetyCases(
         SafetyCase,
         AnalysisCreateRequest,
         SafetyCase,
-        SafetycasesOperationsGenerated,
+        SafetyCasesOperationsGenerated,
     ],
     _ArtifactsMixin,
     _LogsMixin,
@@ -2388,7 +2520,7 @@ class _SafetyCases(
 
         # Make HTTP request to the safetycases workflow logs endpoint
         response = httpx.get(
-            f"{self._client._raw._client._base_url}/safetycases/{id}/logs/workflow",
+            f"{self._client._endpoint}/safetycases/{id}/logs/workflow",
             headers={"Authorization": f"Bearer {self._client._api_token}"},
             params=params,
             verify=not self._insecure,
@@ -2404,11 +2536,10 @@ class _SafetyCases(
         :yield: Individual log entries as they arrive.
         :raises HttpResponseError:
         """
-        # Build WebSocket URL
-        base_url = self._client._raw._client._base_url.replace("https://", "").replace(
-            "http://", ""
+        ws_endpoint = self._client._endpoint.replace("https://", "wss://").replace(
+            "http://", "ws://"
         )
-        ws_url = f"wss://{base_url}/safetycases/{id}/logs/workflow/stream"
+        ws_url = f"{ws_endpoint}/safetycases/{id}/logs/workflow/stream"
 
         # Connect to WebSocket with authentication
         api_token = self._client._api_token
@@ -2420,6 +2551,93 @@ class _SafetyCases(
                 yield log_entry
 
 
+class _Teams:
+    def __init__(
+        self,
+        _client: Client,
+    ):
+        self._client = _client
+        self.__raw_ops = _client.raw.teams
+
+    @property
+    def _insecure(self) -> bool:
+        return self._client.insecure
+
+    @property
+    def _timeout(self) -> Timeout:
+        return self._client.timeout
+
+    @property
+    def _raw_ops(self) -> TeamsOperationsGenerated:
+        return self.__raw_ops
+
+    def get(self, id: str) -> Team:
+        """Get an entity by its .id.
+
+        :param id: The entity ID
+        :return: The entity with the given ID.
+        """
+        return Team.model_validate(self._raw_ops.get(id))
+
+    def label(self, id: str, labels: dict[str, Optional[str]]) -> None:
+        """Label the specified entity with key-value pairs (stored in the ``.labels``
+        field).
+
+        Providing ``None`` for the value deletes the label. Key-value mappings
+        not given in ``labels`` remain unchanged.
+
+        See :class:`~dyff.schema.platform.Label` for a description of the
+        constraints on label keys and values.
+
+        :param id: The ID of the entity to label.
+        :param labels: The label keys and values.
+        """
+        if not labels:
+            return
+        labels = LabelsEditRequest(labels=labels).model_dump(by_alias=True)
+        self._raw_ops.label(id, labels)
+
+    def query(
+        self,
+        *,
+        query: Optional[QueryT] = None,
+        id: Optional[str] = None,
+        account: Optional[str] = None,
+        status: Optional[str] = None,
+        reason: Optional[str] = None,
+        labels: Optional[dict[str, str]] = None,
+        challenge: Optional[str] = None,
+    ) -> list[Team]:
+        """Get all SafetyCase entities matching a query. The query is a set of equality
+        constraints specified as key-value pairs.
+
+        :keyword query:
+        :keyword id:
+        :keyword account:
+        :keyword status:
+        :keyword reason:
+        :keyword labels: Matches entities that are labeled with *all* of the given key-
+            value pairs.
+        :keyword challenge:
+        :raises HttpResponseError:
+        """
+        return [
+            Team.model_validate(obj)
+            for obj in self._raw_ops.query(
+                query=_encode_query(query),
+                id=id,
+                account=account,
+                status=status,
+                reason=reason,
+                labels=_encode_labels(labels),
+                challenge=challenge,
+            )
+        ]
+
+    def edit(self, id: str, edit: TeamEditRequest) -> None:
+        self._raw_ops.edit(id, edit.model_dump(mode="json"))
+
+
 class _Audits(_LogsMixin):
     """Operations on :class:`~dyff.schema.platform.Audit` entities.
 
@@ -2434,15 +2652,18 @@ class _Audits(_LogsMixin):
 
     @property
     def _insecure(self) -> bool:
-        return self._client._insecure
+        return self._client.insecure
 
     @property
     def _timeout(self) -> Timeout:
-        return self._client._timeout
+        return self._client.timeout
+
+    def get(self, id: str) -> Audit:
+        raise NotImplementedError()
 
 
 class _UseCases(
-    _OpsBase[UseCase, ConcernCreateRequest, UseCase, UsecasesOperationsGenerated],
+    _OpsBase[UseCase, ConcernCreateRequest, UseCase, UseCasesOperationsGenerated],
     # _DocumentationMixin,
     _PublishMixin,
 ):
@@ -2512,12 +2733,13 @@ class _UseCases(
         :param id: The ID of the entity.
         :param edit_request: Object containing the edits to make.
         """
-        self._raw_ops.edit_documentation(id, edit_request.dict())
+        self._raw_ops.edit_documentation(id, edit_request.model_dump(by_alias=True))
 
 
 __all__ = [
     "_Artifacts",
     "_Audits",
+    "_Challenges",
     "_Datasets",
     "_Evaluations",
     "_Families",
@@ -2527,7 +2749,9 @@ __all__ = [
     "_Methods",
     "_Models",
     "_Modules",
+    "_Pipelines",
     "_Reports",
     "_SafetyCases",
+    "_Teams",
     "_UseCases",
 ]
